"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _useCatalog = _interopRequireDefault(require("./use-catalog"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const CatalogComponent = _react.default.forwardRef((props, ref) => {
  const {
    component,
    fallbackComponent
  } = props,
        others = _objectWithoutProperties(props, ["component", "fallbackComponent"]);

  const {
    catalog
  } = (0, _useCatalog.default)() || {};

  if (!catalog || !catalog._components) {
    if (process.env.NODE_ENV !== "production") {
      console.error('catalog is not defined. Please, use <CatalogComponent /> in the context of a <CatalogProvider /> with an existing catalog.');
    }

    return null;
  }

  const Component = catalog.getComponent(component);

  if (Component) {
    return _react.default.createElement(Component, _extends({}, others, {
      ref: ref
    }));
  }

  if (fallbackComponent) {
    let FallbackComponent = null;

    if (typeof fallbackComponent === 'string') {
      FallbackComponent = catalog.getComponent(fallbackComponent);
    } else {
      FallbackComponent = fallbackComponent;
    }

    if (FallbackComponent) {
      return _react.default.createElement(FallbackComponent, _extends({}, others, {
        ref: ref
      }));
    }
  }

  if (process.env.NODE_ENV !== "production") {
    const isClient = typeof window !== 'undefined';
    const errorMsg = `CatalogComponent: "${component}" not found in component catalog.`;

    if (isClient) {
      console.error(errorMsg, 'The catalog contains only:', catalog._components);
    } else {
      console.error(errorMsg);
    }
  }

  return null;
});

CatalogComponent.displayName = 'CatalogComponent';
var _default = CatalogComponent;
exports.default = _default;